<?php

/**
 * @file
 * Contains \Drupal\js_injector\Form\RuleDeleteForm.
 */

namespace Drupal\js_injector\Form;

use Drupal\Core\Entity\EntityConfirmFormBase;
use Drupal\Core\Url;

/**
 * Provides a deletion confirmation form for js_injector rule entity.
 */
class RuleDeleteForm extends EntityConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return t('Are you sure you want to delete the rule %name?', array('%name' => $this->entity->label()));
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('js_injector.rule_admin', ['js_injector_rule' => $this->entity->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelRoute() {
    return array(
      'route_name' => 'js_injector.rule_admin',
      'route_parameters' => array(
        'js_injector_rule' => $this->entity->id(),
      ),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function submit(array $form, array &$form_state) {
    // Clean up the JavaScript file.
    \Drupal::service('file_system')->delete(_js_injector_rule_uri($this->entity->id()));
    $this->entity->delete();
    \Drupal::logger('user')->notice('Rule %name has been deleted.', array('%name' => $this->entity->label()));
    \Drupal::messenger()->addMessage(t('Rule %name has been deleted.', array('%name' => $this->entity->label())));
    $form_state['redirect'] = 'admin/config/development/js-injector';
  }
}
